.. czsc documentation master file, created by
   sphinx-quickstart on Sun Oct 23 00:25:49 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to czsc's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: 目录

   ../学习资料
   ../modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
